@@ -146,8 +146,13 @@ class KLExpansion:
         for tag in state.keys():
             if tag == 'C_code':
                 self.C = []
-                for C_code in state[tag]:
-                    code =  marshal.loads( C_code )
+                if isinstance(state[tag],list):
+                    # For new format with anisotropic covariances
+                    for C_code in state[tag]:
+                        code =  marshal.loads( C_code )
+                        self.C.append(types.FunctionType(code, globals(), "C"))
+                else:
+                    code =  marshal.loads( state[tag] )
                     self.C.append(types.FunctionType(code, globals(), "C"))
             else:
                 setattr(self, tag, state[tag])
