@@ -31,7 +31,6 @@ from numpy import linalg as la
 from numpy import random
 from scipy import stats
 import marshal, types
-from mpi4py import MPI
 from time import clock
 from sobol_lib import i4_sobol_generate
 from UQToolbox import object_store
@@ -116,21 +115,22 @@ class Experiments():
     :param bool marshal_f: whether to marshal the function ``f`` or not.
     :param str store_file: file path where to store the computed values
     """
-    
-    f = None
-    dists = None
-    mdist = None
-    
-    params = None
-    f_code = None
-    new_samples = []
-    samples = []
-    results = []
-    store_file = ""
-    
-    serialize_list = ['new_samples','samples','results','f_code','params','store_file']
-    
+        
     def __init__(self, f, params, dists, marshal_f=True, store_file=""):
+
+        self.f = None
+        self.dists = None
+        self.mdist = None
+        
+        self.params = None
+        self.f_code = None
+        self.new_samples = []
+        self.samples = []
+        self.results = []
+        self.store_file = ""
+    
+        self.serialize_list = ['new_samples','samples','results','f_code','params','store_file','serialize_list']
+        
         self.set_f(f)
         self.set_params(params)
         self.set_dists(dists)
