@@ -28,13 +28,13 @@
 
 from _version import __version__
 
-import aux
-from aux import *
+import auxiliary
+from auxiliary import *
 import unittests
 from unittests import *
 
 __all__ = []
-__all__ += aux.__all__
+__all__ += auxiliary.__all__
 __all__ += ["RandomSampling","ModelReduction","gPC","sobol_lib","CutANOVA","mcmc"]
 __all__ += unittests.__all__
 
