@@ -30,8 +30,6 @@ from numpy import linalg as la
 
 from scipy import stats
 
-from mpi4py import MPI
-
 import itertools
 
 from prettytable import PrettyTable
@@ -95,7 +93,7 @@ def gPC_MultiIndex(dist,poly,distPoly,N,NI=[],quadTypes=None,left=None,right=Non
     # Compute Generalized Vandermonde if required
     xs = []
     for i in range(0,DIM):
-        x1D, w = poly[i].Quadrature(N,quadType=quadTypes[i],normed=False,left=left[i], right=right[i], end=end[i])
+        x1D, _ = poly[i].Quadrature(N,quadType=quadTypes[i],normed=False,left=left[i], right=right[i], end=end[i])
         xs.append(x1D)
     V = pp.GradVandermondePascalSimplex(xs, N, np.zeros(DIM,dtype=int), norms=None, warnings=warnings)
     
@@ -104,7 +102,7 @@ def gPC_MultiIndex(dist,poly,distPoly,N,NI=[],quadTypes=None,left=None,right=Non
     
     xs = []
     for i in range(0,DIM):
-        x1D, w = poly[i].Quadrature(NI,quadType=quadTypes[i],normed=False,left=left[i], right=right[i], end=end[i])
+        x1D, _ = poly[i].Quadrature(NI,quadType=quadTypes[i],normed=False,left=left[i], right=right[i], end=end[i])
         xs.append(x1D)
     VI = pp.GradVandermondePascalSimplex(xs, N, np.zeros(DIM,dtype=int), norms=None)
 
@@ -201,7 +199,9 @@ def UQ_PCM_Tensor(solve,params,solvePostProcessing,dists,paramUpdate,polys,dists
         - 'meanSol': estimated mean
         - 'varSol': estimated variance
     """    
-    
+
+    from mpi4py import MPI
+        
     comm = MPI.COMM_WORLD
     myrank = comm.Get_rank()
     
@@ -344,6 +344,8 @@ def UQ_SparseGrid(solve,params,solvePostProcessing,dists,paramUpdate,method,k,sy
             * GQN = Gaussian quadrature for integral with Gaussian weight (Gauss-Hermite)
             * func =  any function provided by the user that accept level l and returns nodes n and weights w for univariate quadrature rule with polynomial exactness 2l-1 as [n w] = feval(func,level)
     """    
+
+    from mpi4py import MPI
     
     comm = MPI.COMM_WORLD
     myrank = comm.Get_rank()
@@ -1011,6 +1013,8 @@ def UQ_MEPCM_Tensor(domain,solve,params,solvePostProcessing,paramUpdate,refOrder
         ``uHatEl``: (list #<multi-dim El>) Galerkin coefficients (available only if method == 'projection')
         ``fEval``: total number of solve evalutations
     """
+
+    from mpi4py import MPI
     
     comm = MPI.COMM_WORLD
     myrank = comm.Get_rank()
