@@ -24,7 +24,7 @@
 
 import sys
 
-from aux import bcolors
+from auxiliary import bcolors
 
 def print_ok(string):
     print bcolors.OKGREEN + "[SUCCESS] " + string + bcolors.ENDC
